@@ -159,3 +159,14 @@ class CartViewTestCase(TestCase):
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.data['customer']['user'], None)
         self.assertNotEqual(response.data['customer']['number'], None)
+
+    def test_get_list_cart(self):
+        CartItem.objects.create(customer=self.customer, count=1, params={}, product=10)
+        response = self.client.get(
+            '/api/v1/cart/',
+            format='json',
+            HTTP_ACCEPT='application/json',
+        )
+
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(len(response.data), 1)
